@@ -1,8 +1,8 @@
 #!/usr/bin/python3
 
 from __future__ import annotations
-from typing import List, Tuple
-from re import compile as reg_compile, Pattern
+from typing import List, Tuple, Dict
+from re import compile as reg_compile, Pattern, IGNORECASE, ASCII
 from functools import reduce
 from datetime import datetime
 
@@ -87,6 +87,19 @@ class Chat(object):
                                                                            cur.messages, False) else acc,
                                                                        self.users, None)
 
+    def getConcatenatedMessagesForEachParticipant(self) -> Dict[str, str]:
+        '''
+            Concatenating all messages sent to this chat, by each participant
+        '''
+        _mediaOmitted = reg_compile(r'\<media\s+omitted\>', flags=IGNORECASE)
+        _asciiWords = reg_compile(r'\w+', flags=ASCII)
+
+        return dict(map(lambda e: (e.name,
+                                   '\n'.join(filter(lambda e: not e.isnumeric(),
+                                                    _asciiWords.findall('\n'.join(
+                                                        filter(lambda e: not _mediaOmitted.match(e),
+                                                               map(lambda e: e.content, e.messages))))))), self.users))
+
     @staticmethod
     def importFromText(filePath: str) -> Chat:
         '''
