@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
 from __future__ import annotations
-from os.path import abspath, dirname, exists
+from os.path import abspath, dirname, exists, join
 from os import mkdir
 from functools import reduce
 from typing import Dict, List, Tuple, Any
@@ -13,6 +13,7 @@ from matplotlib.ticker import MultipleLocator, PercentFormatter, StrMethodFormat
 from matplotlib.dates import HourLocator, DateFormatter, MinuteLocator, MonthLocator, DayLocator
 import ray
 import seaborn as sns
+from wordcloud import WordCloud
 
 from .model.chat import Chat
 from .model.message import Message, MessageIndex
@@ -570,6 +571,23 @@ def plotActivityHeatMap(data: List[Message], targetPath: str, title: str) -> boo
     except Exception:
         return False
 
+@ray.remote
+def plotWordCloudForEachUser(chat: Chat, sinkDirectory: str, extention: str) -> bool:
+    '''
+        Plotting word cloud for each chat participant, with
+        messages they sent in chat
+    '''
+    try:
+        for k, v in chat.getConcatenatedMessagesForEachParticipant().items():
+            wc = WordCloud(width=1600, height=900, regexp=r'\S+')
+
+            wc.generate(v)
+            wc.to_file(join(sinkDirectory, f'wordCloudOfMessagesBy{"_".join(k.split(" "))}.{extention}'))
+
+        return True
+    except Exception:
+        return False
+
 
 if __name__ == '__main__':
     print('[!]This module is designed to be used as a backend handler')
